#pragma NOIV					// Do not generate interrupt vectors
//-----------------------------------------------------------------------------
//	File:		periph.c
//	Contents:	Hooks required to implement USB peripheral function.
//
//	Copyright (c) 1997 AnchorChips, Inc. All rights reserved
//-----------------------------------------------------------------------------
#include <ezusb.h>
#include <ezregs.h>

extern BOOL	GotSUD;			// Received setup data flag
extern BOOL	Sleep;
extern BOOL	Rwuen;
extern BOOL	Selfpwr;

BYTE	Configuration;		// Current configuration
BYTE	AlternateSetting;	// Alternate settings
BYTE  suspCount;
//-----------------------------------------------------------------------------
// Task Dispatcher hooks
//	The following hooks are called by the task dispatcher.
//-----------------------------------------------------------------------------

typedef unsigned char u8;
typedef signed char s8;
typedef unsigned short u16;
typedef signed short s16;
typedef unsigned long u32;
typedef signed long s32;

/* BulkReadCounter */
xdata volatile u8  br_en;
xdata volatile u8  br_cntl;
xdata volatile u8  br_cntm;
xdata volatile u8  br_cnth;

void TD_Init(void) 				// Called once at startup
{
	// Enable endpoints 0-7 IN and OUT
	IN07VAL |= bmEP1 + bmEP2 + bmEP4 + bmEP5 + bmEP6 + bmEP7;
	OUT07VAL |= bmEP1 + bmEP2 + bmEP4 + bmEP6 + bmEP7;

   // Enable interrupts for the OUT endpoints
//   IN07IRQ  |= bmEP2;
   OUT07IEN |= bmEP1 + bmEP2 + bmEP4 + bmEP6 + bmEP7;

   suspCount = 1;

   Rwuen = TRUE;				// Enable remote-wakeup

//   USBPAIR=0x09;	//2IN&3IN 2OUt&3OUt is paired
   USBPAIR=bmPR2IN|bmPR2OUT|bmPR4OUT;

   CPUCS=0x02;		//CLK24OE enable

   PORTACFG=0x30;
   PORTBCFG=0x00;
   PORTCCFG=0x00;

	// clear Bulk Read/Write counter
	br_en = 0;

	// bus timming
	FASTXFR=0x40;
}

void TD_Poll(void){
	u8 i;

	// BulkReadSetup Poling
	if(br_en)
	{
		if(!(IN2CS & bmEPBUSY))
		{
			AUTOPTRL=0x00;
			AUTOPTRH=0x7e;
			if(br_cntm | br_cnth)
			{
				// FullBlock
				for(i=0;i<8;i++)
				{
					AUTODATA=0;
					AUTODATA=0;
					AUTODATA=0;
					AUTODATA=0;
					AUTODATA=0;
					AUTODATA=0;
					AUTODATA=0;
					AUTODATA=0;
				}
				IN2BC=64;
				// decrement one block
				br_cntm--;
				if(br_cntm==0xff)
					br_cnth--;
			}
			else
			{
				// LastBlock
				for(i=0;i<br_cntl;i++)
					AUTODATA=0;
				IN2BC=br_cntl;
				br_cntl = 0;
			}
			br_en = br_cntl | br_cntm | br_cnth;
		}
	}
}

BOOL TD_Suspend(void) 			// Called before the device goes into suspend mode
{
	return(TRUE);
}

BOOL TD_Resume(void) 			// Called after the device resumes
{
	return(TRUE);
}

//-----------------------------------------------------------------------------
// Device Request hooks
//	The following hooks are called by the end point 0 device request parser.
//-----------------------------------------------------------------------------

BOOL DR_GetDescriptor(void)
{
	return(TRUE);
}

BOOL DR_SetConfiguration(void)	// Called when a Set Configuration command is received
{
	Configuration = SETUPDAT[2];
	return(TRUE);				// Handled by user code
}

BOOL DR_GetConfiguration(void)	// Called when a Get Configuration command is received
{
	IN0BUF[0] = Configuration;
	EZUSB_SET_EP_BYTES(IN0BUF_ID,1);
	return(TRUE);				// Handled by user code
}

BOOL DR_SetInterface(void) 		// Called when a Set Interface command is received
{
	AlternateSetting = SETUPDAT[2];
	return(TRUE);				// Handled by user code
}

BOOL DR_GetInterface(void) 		// Called when a Set Interface command is received
{
	IN0BUF[0] = AlternateSetting;
	EZUSB_SET_EP_BYTES(IN0BUF_ID,1);
	return(TRUE);				// Handled by user code
}

BOOL DR_GetStatus(void)
{
	return(TRUE);
}

BOOL DR_ClearFeature(void)
{
	return(TRUE);
}

BOOL DR_SetFeature(void)
{
	return(TRUE);
}

#define EZUSB_UNARM_EP(ep_id)  			EPIO[ep_id].cntrl = bmEPBUSY

BOOL DR_VendorCmnd(void)
{
   return(TRUE);
}

//-----------------------------------------------------------------------------
// USB Interrupt Handlers
//	The following functions are called by the USB interrupt jump table.
//-----------------------------------------------------------------------------


// Setup Data Available Interrupt Handler
void ISR_Sudav(void) interrupt 0
{
	GotSUD = TRUE;				// Set flag


	EZUSB_IRQ_CLEAR();
	USBIRQ = bmSUDAV;			// Clear SUDAV IRQ
}

// Setup Token Interrupt Handler
void ISR_Sutok(void) interrupt 0
{
	EZUSB_IRQ_CLEAR();
	USBIRQ = bmSUTOK;			// Clear SUTOK IRQ
}

void ISR_Sof(void) interrupt 0
{
	EZUSB_IRQ_CLEAR();
	USBIRQ = bmSOF;				// Clear SOF IRQ
}

void ISR_Ures(void) interrupt 0
{
   //
   // Arm all of the OUT endpoints so they can accept data
   //
   EPIO[OUT1BUF_ID].bytes = 0;
   EPIO[OUT2BUF_ID].bytes = 0;
// EPIO[OUT3BUF_ID].bytes = 0;
   EPIO[OUT4BUF_ID].bytes = 0;
   EPIO[OUT5BUF_ID].bytes = 0;
   EPIO[OUT6BUF_ID].bytes = 0;
   EPIO[OUT7BUF_ID].bytes = 0;

	EZUSB_IRQ_CLEAR();
	USBIRQ = bmURES;			// Clear URES IRQ
}

void ISR_IBN(void) interrupt 0
{
   // ISR for the IN Bulk NAK (IBN) interrupt.
}

void ISR_Susp(void) interrupt 0
{
   Sleep = TRUE;

   EZUSB_IRQ_CLEAR();
   USBIRQ = bmSUSP;
}

void ISR_Ep0in(void) interrupt 0
{
}

void ISR_Ep0out(void) interrupt 0
{
}

void ISR_Ep1in(void) interrupt 0
{
}

#define JTAGFW_CDIR 0x00 // 2:0 (cmd)(PCdir) PortC Direction set
#define JTAGFW_CSET 0x10 // 2:0 (cmd)(PCout) PortC Outport
#define JTAGFW_CGET 0x20 // 1:1 (cmd)->(PCin) , PortC Input
#define JTAGFW_XMW  0x30 // 3:0 (cmd)(ad[7..0])(ad[15..8])(xdata) Write XDATA
#define JTAGFW_XMR  0x40 // 2:1 (cmd)(ad[7..0])(ad[15..8])->(xdata) Read XDATA
#define JTAGFW_READ 0x50 // 3:? (cmd)(LEN[5..0])(LEN[13..6]),(LEN[21..14])->(FREAD)xLEN
#define	JTAGFW_BUS  0xf0 // 2:0 (cmd,strech)(FASTXFR) set bus mode

void ISR_Ep1out(void) interrupt 0{
	u8 i,r;
	u8 *xptr;

	r=0;
	for(i=0;i<OUT1BC;i++){
		switch(OUT1BUF[i] & 0xf0)
		{
		case JTAGFW_CDIR:
			OEC=OUT1BUF[++i];
			break;
		case JTAGFW_CSET:
			OUTC=OUT1BUF[++i];
			break;
		case JTAGFW_CGET:
			IN2BUF[r++]=PINSC;
			break;
		case JTAGFW_XMW:
			xptr =  (u8 *)OUT1BUF[++i];
			xptr += (OUT1BUF[++i]<<8);
			*xptr = OUT1BUF[++i];
			break;
		case JTAGFW_XMR:
			xptr =  (u8 *)OUT1BUF[++i];
			xptr += (OUT1BUF[++i]<<8);
			IN2BUF[r++]=*xptr;
			break;
		case JTAGFW_READ:
			br_cntl=OUT1BUF[++i] & 0x3f;
			br_cntm=OUT1BUF[++i];
			br_cnth=OUT1BUF[++i];
			br_en = br_cntl | br_cntm | br_cnth;
			break;
		case JTAGFW_BUS:
			if((OUT1BUF[i]&0x0f)==0)
				CKCON=0;
			else
				CKCON=1;
			FASTXFR=OUT1BUF[++i] | 0x40;
			break;
		}
	}
	if(r!=0){
		IN2BC=r;
	}
	OUT1BC = 0;
	EZUSB_IRQ_CLEAR();
	OUT07IRQ = bmEP1;
}

void ISR_Ep2in(void) interrupt 0{
#if 0
	// Ready to Ep4out
	OUT07IRQ = bmEP4;

	EZUSB_IRQ_CLEAR();
	IN07IRQ = bmEP2;
#endif
}

// ASM routine
extern void WritePortCReadX(void); // TX&RX AUTOPTR x OUT4BC
extern void WriteX(void);           // TX AUTOPTR x OUT2BC

// FWRITE
void ISR_Ep2out(void) interrupt 0{
//	u8 j;

	//Fast Write
	AUTOPTRL=0xc0;
	AUTOPTRH=0x7d;
#if 1
	WriteX(); /* ASM routine */
#else
	for(j=0;j<OUT2BC;j++)
		i=AUTODATA;
#endif
	OUT2BC = 0;
	EZUSB_IRQ_CLEAR();
	OUT07IRQ = bmEP2;
}

void ISR_Ep3in(void) interrupt 0{
}

void ISR_Ep3out(void) interrupt 0{
}

void ISR_Ep4in(void) interrupt 0{
}

// FWRITE & PORTC READ
void ISR_Ep4out(void) interrupt 0{

	//Fast Write
	AUTOPTRL=0xc0; // OUT4BUF;
	AUTOPTRH=0x7c; // OUT4BUF>>8;

	/* wait for last ReadBlock */
	while(IN2CS & bmEPBUSY);

	WritePortCReadX(); // ASM routine TX OUT4BUF & get IN2BUF
	IN2BC=OUT4BC;

	OUT4BC = 0;
	EZUSB_IRQ_CLEAR();
#if 0
	// if EP2IN is busy , next IRQ is pending
	if(!(IN2CS & bmEPBUSY))
#endif
		OUT07IRQ = bmEP4;
}

void ISR_Ep5in(void) interrupt 0{
}

void ISR_Ep5out(void) interrupt 0{
	OUT5BC = 0;
	EZUSB_IRQ_CLEAR();
	OUT07IRQ = bmEP5;
}

void ISR_Ep6in(void) interrupt 0{
}

void ISR_Ep6out(void) interrupt 0{
	OUT6BC = 0;
	EZUSB_IRQ_CLEAR();
	OUT07IRQ = bmEP6;
}

void ISR_Ep7in(void) interrupt 0{
}

void ISR_Ep7out(void) interrupt 0{
	OUT7BC = 0;
	EZUSB_IRQ_CLEAR();
	OUT07IRQ = bmEP7;
}
